@@ -3,7 +3,7 @@ from ..MetaDataObject.core.Container import Container
 
 
 class Subsystem(Container):
-    pass
+    help_file_number = 0
 
     def decode_object(self, src_dir, file_name, dest_dir, dest_path, version, header_data):
         super(Subsystem, self).decode_object(src_dir, file_name, dest_dir, dest_path, version, header_data)
