@@ -95,8 +95,9 @@ class MetaDataObject(MetaObject):
             except FileNotFoundError:
                 return
             self.encode_object(src_dir, file_name, dest_dir, version)
+            tasks = self.encode_includes(src_dir, file_name, dest_dir, version)
             self.write_encode_object(dest_dir)
-            return self.encode_includes(src_dir, dest_dir)
+            return tasks
         except Exception as err:
             raise ExtException(
                 parent=err,
