@@ -1,5 +1,6 @@
 import re
 
+from .Form803Elements.FormElement import FormElement, FormParams, FormProps, FormCommands, calc_offset
 from .Form8x import Form8x
 from ... import helper
 from ...ext_exception import ExtException
@@ -13,6 +14,12 @@ class Form803(Form8x):
     double_quotes = re.compile(r'("")')
     quotes = re.compile(r'(")')
 
+    def __init__(self):
+        super().__init__()
+        self.command_panels = []
+        self.params = []
+        self.commands = []
+
     def decode_data(self, src_dir, uuid):
         _header_obj = self.get_decode_obj_header(self.header['data'])
         self.header['Включать в содержание справки'] = _header_obj[1][2]
@@ -35,6 +42,7 @@ class Form803(Form8x):
         try:
             form = helper.json_read(src_dir, f'{uuid}.0.json')
         except FileNotFoundError:
+            self.form.append([])
             return
         try:
             _code = helper.str_decode(self.getset_form_code(form, 'Код в отдельном файле', self.header))
@@ -46,6 +54,66 @@ class Form803(Form8x):
             raise ExtException(parent=err, detail=self.header['uuid'])
         self.form.append(form)
 
+    def decode_includes(self, src_dir, dest_dir, dest_path, header_data):
+        if not self.form[0]:
+            return
+        try:
+            supported_form = ['4-49', '3-49']  # not supported 27-18, контур вероятно обычные формы
+            current_form = f'{self.form[0][0][0]}-{self.form[0][0][1][0]}'
+            if current_form not in supported_form:
+                return
+        except:
+            return
+
+        try:
+            self.decode_elements(src_dir, dest_dir, dest_path, header_data)
+            self.params = FormParams.decode_list(self, self.form[0][0])
+            self.commands = FormCommands.decode_list(self, self.form[0][0])
+            self.props = FormProps.decode_list(self, self.form[0][0])
+        except Exception as err:
+            raise ExtException(parent=err, message='Ошибка при разборе формы')
+
+    def decode_elements(self, src_dir, dest_dir, dest_path, header_data):
+        try:
+            index = self.get_form_elem_index()
+            root_data = self.form[0][0][1]
+
+            # index_panel_count = index[1]
+            # form_panels_count = int(root_data[index_panel_count])
+            # if form_panels_count:
+            #     self.command_panels = [root_data[index_panel_count + 1]]
+            #     root_data[index_panel_count] = 'В отдельном файле'
+            #     del root_data[index_panel_count + 1]
+
+            index_root_element_count = index[0]
+            form_items_count = int(root_data[index_root_element_count])
+            if form_items_count:
+                self.elements = FormElement.decode_list(self, root_data, index_root_element_count)
+            pass
+        except Exception as err:
+            raise ExtException(parent=err, message='Ошибка при разборе формы')
+
+    def get_form_elem_index(self):
+        try:
+            root_data = self.form[0][0][1]
+            index_command_panel_count = calc_offset([(18, 2)], root_data) + 2
+            command_panel_count = int(root_data[index_command_panel_count])
+            index_root_elem_count = index_command_panel_count + command_panel_count + 1
+            return index_root_elem_count, index_command_panel_count
+        except Exception as err:
+            raise ExtException(
+                message='случай требующий анализа, предоставьте образец формы разработчикам',
+                detail=f'{self.header["name"]}, {err}')
+
+    def write_decode_object(self, dest_dir, dest_path, file_name, version):
+        super().write_decode_object(dest_dir, dest_path, file_name, version)
+        if self.commands:
+            helper.json_write(self.commands, self.new_dest_dir, f'{file_name}.commands{self.ver}.json')
+        if self.params:
+            helper.json_write(self.params, self.new_dest_dir, f'{file_name}.params{self.ver}.json')
+        if self.command_panels:
+            helper.json_write(self.command_panels, self.new_dest_dir, f'{file_name}.panels{self.ver}.json')
+
     @classmethod
     def get_last_level_array(cls, data):
         while True:
@@ -159,6 +227,38 @@ class Form803(Form8x):
             pass
         return self.form
 
+    def encode_includes(self, src_dir, file_name, dest_dir, version):
+        if not self.form[0]:
+            return
+        try:
+            supported_form = ['4-49']
+            if f'{self.form[0][0][0]}-{self.form[0][0][1][0]}' not in supported_form:
+                return
+        except:
+            return
+        try:
+            self.encode_elements(src_dir, file_name, dest_dir, version)
+            FormParams.encode_list(self, src_dir, file_name, version)
+            FormCommands.encode_list(self, src_dir, file_name, version)
+            FormProps.encode_list(self, src_dir, file_name, version)
+        except Exception as err:
+            raise ExtException(parent=err, message='Ошибка при разборе формы')
+
+    def encode_elements(self, src_dir, file_name, dest_dir, version):
+        index = self.get_form_elem_index()
+        root_data = self.form[0][0][1]
+
+        # index_panel_count = index[1]
+        # form_panels_count = int(root_data[index_panel_count])
+        # if form_panels_count == 'В отдельном файле':
+        #     self.command_panels = helper.json_read(src_dir, f'{file_name}.panels{version}.json')
+
+        index_root_element_count = index[0]
+        if root_data[index_root_element_count] == 'Дочерние элементы отдельно':
+            self.elements = helper.json_read(src_dir, f'{file_name}.elements{version}.json')
+            # root_data[index_root_element_count] = str(len(self.elements))
+            FormElement.encode_list(self, self.elements, root_data, index_root_element_count)
+
     def write_encode_object(self, dest_dir):
         if self.header['Тип формы'] == OLD_FORM:
             self.write_old_encode_object(dest_dir)
